<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Country;
use App\User;
use Illuminate\Http\Request;

class UsersController extends Controller
{

    public function index()
    {
        $rows = User::whereType('user')->latest()->get();
        return view('admin.users.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $countries = Country::all();
        return view('admin.users.create',compact('countries'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'username' => 'required',
            'email' => 'required|email|unique:users',
            'mobile' => 'required|unique:users,mobile',
            'country_id' => 'required|exists:countries,id',
            'image' => 'image',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active'
        ]);
        $user = new User();
        $user['mobile'] = $request['mobile'];
        $user['email'] = $request['email'];
        $user['username'] = $request['username'];
        $user['country_id'] = $request['country_id'];
        $user['password'] = bcrypt($request['password']);
        $user['type'] = 'user';
        $user['status'] = 'active';
        if ($request->hasFile('image')) {
            $filename = time() . '.' . $request['image']->getClientOriginalExtension();
            $request['image']->move(public_path('images/users'), $filename);
            $user->image = $filename;
        }
        $user->save();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('users.index');

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        $countries = Country::all();
        return view('admin.users.edit', compact('row','countries'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'username' => 'required',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile,' . $id,
            'country_id' => 'required|exists:countries,id',
            'image' => 'image',
            'status' => 'required|in:active,not_active'
        ]);
        $user = User::find($id);
        $user['mobile'] = $request['mobile'];
        $user['email'] = $request['email'];
        $user['username'] = $request['username'];
        $user['country_id'] = $request['country_id'];
        $user['password'] = bcrypt($request['password']);
        $user['type'] = 'user';
        $user['status'] = 'active';
        if ($request->hasFile('image')) {
            $filename = time() . '.' . $request['image']->getClientOriginalExtension();
            $request['image']->move(public_path('images/users'), $filename);
            $user->image = $filename;
        }
        $user->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('users.index');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
