<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\BanksResource;
use App\Models\Bank;
use App\Models\BankTransfer;
use Illuminate\Http\Request;
use JWTAuth;

class BanksController extends Controller
{
    public function index()
    {

        $rows = Bank::paginate(10);
        return BanksResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }


    public function commission(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'amount' => 'required',
            'image' => 'required|image',
            'full_name' => 'required',
            'bank_id' => 'required|exists:banks,id'
        ]);
        if ($validator->passes()) {
            $transfer = new BankTransfer();
            $transfer['user_id'] = $user->id;
            $transfer['amount'] = $request['amount'];
            $transfer['full_name'] = $request['full_name'];
            $transfer['bank_id'] = $request['bank_id'];
            if ($request->hasFile('image')) $transfer->setImageAttribute();
            $transfer->save();



            return response()->json(['value' => true, 'data' => \Lang::get('data.transfer_done')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
}
