<?php

namespace App\Http\Controllers\web;

use App\Http\Controllers\Controller;
use App\Http\Middleware\Lang;
use App\Models\Category;
use App\Models\Comment;
use App\Models\Country;
use App\Models\Product;
use App\Models\ProductImage;
use App\Models\Report;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class ProductsController extends Controller
{
    public function product_details($id)
    {
        try {
            $product = Product::findOrFail($id);

            return view('web.products.show', compact('product'));
        } catch (\Exception $exception) {
            return view('web.errors.404');
        }
    }

    public function report_product(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'product_id' => 'required'
        ]);
        if ($validator->passes()) {

            $title = \Lang::get('site.reported');
            $confirmButtonText = \Lang::get('site.done');

            Report::create([
                'user_id' => \Auth::user()->id,
                'product_id' => $request['product_id']
            ]);

            return response()->json(['status' => 1, 'msg' => $title, 'title' => $title, 'confirm_text' => $confirmButtonText]);

        } else {
            $title = \Lang::get('site.error');
            $confirmButtonText = \Lang::get('site.close');
            return response()->json(['status' => 0, 'msg' => $validator->errors()->first(), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        }
    }
    public function delete_product($id){
        Product::destroy($id);
        toast(\Lang::get('site.deleted'),'success');
        return redirect()->route('home_categories');
    }

    public function post_comment($id, Request $request)
    {

        $request->validate([
            'comment' => 'required'
        ]);
        Comment::create([
            'product_id' => $id,
            'comment' => $request['comment'],
            'user_id' => \Auth::user()->id
        ]);

        toast(\Lang::get('site.commented'), 'success', 'top-left');
        return redirect()->back();

    }

    public function new_product()
    {
        $categories = Category::where('parent_id', null)->get();
        $countries = Country::all();
        return view('web.products.create', compact('categories', 'countries'));
    }

    public function get_sub_categories(Request $request)
    {
        $sub_categories = Category::whereParentId($request['category_id'])->get();
        $html_data = view('web.products.select_sub', compact('sub_categories'))->render();
        return response()->json(['status' => 1, 'html_data' => $html_data]);
    }

    public function post_product(Request $request)
    {

         $request->validate([
            'title' => 'required',
            'description' => 'required',
            'category_id' => 'required|exists:categories,id',
            'sub_category_id' => 'exists:categories,id',
            'country_id' => 'required|exists:countries,id',
            'images' => 'required',
            'size' => 'required',
            'type' => 'required',
            'year' => 'required',
            'shape' => 'required',
        ], [
            'title.required' => \Lang::get('site.title_required'),
            'description.required' => \Lang::get('site.description_required'),
            'category_id.required' => \Lang::get('site.category_required'),
            'country_id.required' => \Lang::get('site.country_required'),
            'images.required' => \Lang::get('site.images_required'),
            'size.required' => \Lang::get('site.size_required'),
            'type.required' => \Lang::get('site.type_required'),
            'year.required' => \Lang::get('site.year_required'),
            'shape.required' => \Lang::get('site.shape_required'),
        ]);
        $product = new Product();
        $product['title'] = $request['title'];
        $product['description'] = $request['description'];
        $product['category_id'] = $request['category_id'];
        $product['sub_category_id'] = $request['sub_category_id'];
        $product['country_id'] = $request['country_id'];
        $product['size'] = $request['size'];
        $product['shape'] = $request['shape'];
        $product['year'] = $request['year'];
        $product['type'] = $request['type'];
        $product['show_mobile'] = $request['show_mobile'] ? $request['show_mobile'] : 'false';
        $product['receive_notification'] = $request['receive_notification'] ? $request['receive_notification'] : 'false';
        $product['contact_type'] = $request['contact_type'];
        $product['user_id'] = \Auth::user()->id;
        $product->save();
        $i = 1;
        if (count($request->images) > 0) {
            foreach ($request->images as $image) {
                $filename = $i . time() . '.' . $image->getClientOriginalExtension();
                $image->move(public_path('images/products'), $filename);
                $product_image = new ProductImage();
                $product_image['image'] = $filename;
                $product_image['product_id'] = $product->id;
                $product_image->save();
                $i ++ ;
            }
        }

        toast(\Lang::get('site.product_created'), 'success');
        return redirect()->route('product_details', $product->id);

    }
}
