<?php

namespace App;

use App\Models\Bank;
use App\Models\Country;
use App\Models\Notification;
use App\Models\Product;
use App\Models\Room;
use App\Models\UserToken;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Tymon\JWTAuth\Contracts\JWTSubject;

class User extends Authenticatable implements JWTSubject
{
    use Notifiable;

    public function getJWTIdentifier()
    {
        return $this->getKey();
    }

    public function getJWTCustomClaims()
    {
        return [];
    }

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = array('username', 'image', 'email', 'mobile', 'status', 'password', 'code', 'country_id', 'type');


    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];


    // relations
    public function country()
    {
        return $this->belongsTo(Country::class, 'country_id');
    }

    public function tokens()
    {
        return $this->hasMany(UserToken::class, 'user_id');
    }

    public function products()
    {
        return $this->hasMany(Product::class, 'user_id');
    }



    public function favourite_products()
    {
        return $this->belongsToMany(Product::class, 'favourite', 'user_id', 'product_id');
    }

    public function notifications()
    {
        return $this->hasMany(Notification::class, 'user_id');
    }

    public function sending_rooms()
    {
        return $this->hasMany(Room::class, 'sender_id');
    }

    public function receiver_rooms()
    {
        return $this->hasMany(Room::class, 'receiver_id');
    }

}
